@@ -92,7 +92,8 @@ public:
     QSGNodeUpdater *nodeUpdater() const;
     void setNodeUpdater(QSGNodeUpdater *updater);
     inline QSGMaterialShader::RenderState state(QSGMaterialShader::RenderState::DirtyStates dirty) const;
-    virtual void setCustomRenderMode(const QByteArray &) { };
+    virtual void setCustomRenderMode(const QByteArray &) { }
+    virtual void releaseCachedResources() { }
 
     void clearChangedFlag() { m_changed_emitted = false; }
 
@@ -118,11 +119,13 @@ private:
     QSGNodeUpdater *m_node_updater;
 
     QSet<QSGNode *> m_nodes_to_preprocess;
+    QSet<QSGNode *> m_nodes_dont_preprocess;
 
     const QSGBindable *m_bindable;
 
     uint m_changed_emitted : 1;
     uint m_is_rendering : 1;
+    uint m_is_preprocessing : 1;
 };
 
 class Q_QUICK_PRIVATE_EXPORT QSGBindable
